# ML Caboodle

* Author: Marius Helf 
  ([helfsmarius@gmail.com](mailto:helfsmarius@gmail.com))

All the stuff that doesn't have another home

# Changelog

## 0.2.2
* chore: bump scikit-learn dependency to 1.0.0

## 0.2.1
* fix: speculative rounds not removed when out of candidates

## 0.2.0
* feature: BackwardFeatureElimination
* various bugfixes

## 0.1.1
* fix: ForwardFeatureSelection: return correct features when stopping
  after speculative rounds.
* improve logging output


## 0.1.0

* Initial release

# License

[MIT](https://choosealicense.com/licenses/mit)


